package com.jz.dmp.modules.dao;

import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceListDto;
import com.jz.dmp.modules.controller.DataIntegration.bean.DataSourceListReq;
import com.jz.dmp.modules.model.DmpSyncingDatasource;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 数据源配置(DmpSyncingDatasource)表数据库访问层
 *
 * @author Bellamy
 * @since 2020-12-24 14:09:59
 */
public interface DmpSyncingDatasourceDao {

    /**
     * 通过ID查询单条数据
     *
     * @param id 主键
     * @return 实例对象
     */
    DmpSyncingDatasource queryById(Integer id);

    /**
     * 查询指定行数据
     *
     * @param offset 查询起始位置
     * @param limit  查询条数
     * @return 对象列表
     */
    List<DmpSyncingDatasource> queryAllByLimit(@Param("offset") int offset, @Param("limit") int limit);


    /**
     * 通过实体作为筛选条件查询
     *
     * @param dmpSyncingDatasource 实例对象
     * @return 对象列表
     */
    List<DmpSyncingDatasource> queryAll(DmpSyncingDatasource dmpSyncingDatasource);

    /**
     * 新增数据
     *
     * @param dmpSyncingDatasource 实例对象
     * @return 影响行数
     */
    int insert(DmpSyncingDatasource dmpSyncingDatasource);

    /**
     * 批量新增数据（MyBatis原生foreach方法）
     *
     * @param entities List<DmpSyncingDatasource> 实例对象列表
     * @return 影响行数
     */
    int insertBatch(@Param("entities") List<DmpSyncingDatasource> entities);

    /**
     * 批量新增或按主键更新数据（MyBatis原生foreach方法）
     *
     * @param entities List<DmpSyncingDatasource> 实例对象列表
     * @return 影响行数
     */
    int insertOrUpdateBatch(@Param("entities") List<DmpSyncingDatasource> entities);

    /**
     * 修改数据
     *
     * @param dmpSyncingDatasource 实例对象
     * @return 影响行数
     */
    int update(DmpSyncingDatasource dmpSyncingDatasource);

    /**
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 影响行数
     */
    int deleteById(Integer id);

    /**
     * 数据源列表查询
     *
     * @param req
     */
    List<DataSourceListDto> queryDataSourceListPage(DataSourceListReq req) throws Exception;

    void delDataSourceById(@Param("ids") String[] ids) throws Exception;

    List<Map> queryDatasourceType() throws Exception;

    List<Map> queryGroupDatasourceType() throws Exception;
}